==> haskell-aeson-diff-1.1.0.13-211-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-diff
version:              1.1.0.13
visibility:           public
id:                   aeson-diff-1.1.0.13-G9CdrXFEowH4pAX22rLzRK
key:                  aeson-diff-1.1.0.13-G9CdrXFEowH4pAX22rLzRK
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Thomas Sutton
homepage:             https://github.com/ysangkok/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  055fe4bb3cfa6f36852f8f697401f4b7
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-diff
hs-libraries:         HSaeson-diff-1.1.0.13-G9CdrXFEowH4pAX22rLzRK
depends:
    aeson-2.1.2.1-8kv8xeVfmZaCzdZG9aqfKb base-4.17.2.1
    bytestring-0.11.5.3
    edit-distance-vector-1.0.0.4-LNKpmjr4VfSI4P1uBqWPHx
    scientific-0.3.8.0-4NIM1ptKK7Y3EgpQdVTV5l text-2.0.2
    vector-0.13.2.0-B39FQf4cXUZ2GlwNF0TDTd

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-diff-1.1.0.13-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-diff
version:              1.1.0.13
visibility:           public
id:                   aeson-diff-1.1.0.13-5NKOiihBza44REzw3Gy9NE
key:                  aeson-diff-1.1.0.13-5NKOiihBza44REzw3Gy9NE
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Thomas Sutton
homepage:             https://github.com/ysangkok/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  940977d2e42c60a7b8d9b234f3c4ba97
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-diff
hs-libraries:         HSaeson-diff-1.1.0.13-5NKOiihBza44REzw3Gy9NE
depends:
    aeson-2.1.2.1-KxhFBZPQYXiG3TO3nhA4Kq base-4.17.2.1
    bytestring-0.11.5.3
    edit-distance-vector-1.0.0.4-BLN8RIlWbuSFbOpseJ4deB
    scientific-0.3.8.0-4yENNWrElASJBAecoCEn1P text-2.0.2
    vector-0.13.2.0-cop25r7TnE5vewvd3oOyK

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
